#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger-lib
version:              1.52.1
visibility:           public
id:                   hledger-lib-1.52.1-43HfShhLTNJHhMAwtVPfbH
key:                  hledger-lib-1.52.1-43HfShhLTNJHhMAwtVPfbH
license:              GPL-3.0-or-later
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             A library providing the core functionality of hledger
description:
    This library contains hledger'\''s core functionality.
    It is used by most hledger* packages so that they support the same
    command line options, file formats, reports, etc.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting.

    See also:

    - https://hledger.org - hledger'\''s home page

    - https://hledger.org/dev.html - starting point for hledger'\''s developer docs

    - https://hackage.haskell.org/package/hledger-lib/docs/Hledger.html - starting point for hledger'\''s haddock docs

category:             Finance
abi:                  6834bd43ed48b1fe808f3bd1d1c87c56
exposed:              True
exposed-modules:
    Hledger Hledger.Data Hledger.Data.Account Hledger.Data.AccountName
    Hledger.Data.Amount Hledger.Data.BalanceData Hledger.Data.Balancing
    Hledger.Data.Currency Hledger.Data.Dates Hledger.Data.DayPartition
    Hledger.Data.Errors Hledger.Data.Journal Hledger.Data.JournalChecks
    Hledger.Data.JournalChecks.Ordereddates
    Hledger.Data.JournalChecks.Uniqueleafnames Hledger.Data.Json
    Hledger.Data.Ledger Hledger.Data.Period Hledger.Data.PeriodData
    Hledger.Data.PeriodicTransaction Hledger.Data.Posting
    Hledger.Data.RawOptions Hledger.Data.StringFormat
    Hledger.Data.Timeclock Hledger.Data.Transaction
    Hledger.Data.TransactionModifier Hledger.Data.Types
    Hledger.Data.Valuation Hledger.Query Hledger.Read
    Hledger.Read.Common Hledger.Read.CsvReader
    Hledger.Read.InputOptions Hledger.Read.JournalReader
    Hledger.Read.RulesReader Hledger.Read.TimeclockReader
    Hledger.Read.TimedotReader Hledger.Reports
    Hledger.Reports.AccountTransactionsReport
    Hledger.Reports.BalanceReport Hledger.Reports.BudgetReport
    Hledger.Reports.EntriesReport Hledger.Reports.MultiBalanceReport
    Hledger.Reports.PostingsReport Hledger.Reports.ReportOptions
    Hledger.Reports.ReportTypes Hledger.Utils Hledger.Utils.Debug
    Hledger.Utils.IO Hledger.Utils.Parse Hledger.Utils.Regex
    Hledger.Utils.String Hledger.Utils.Test Hledger.Utils.Text
    Hledger.Write.Beancount Hledger.Write.Csv Hledger.Write.Html
    Hledger.Write.Html.Attribute Hledger.Write.Html.Blaze
    Hledger.Write.Html.HtmlCommon Hledger.Write.Html.Lucid
    Hledger.Write.Ods Hledger.Write.Spreadsheet Text.Tabular.AsciiWide
    Text.WideString

hidden-modules:       Paths_hledger_lib
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hledger-lib-1.52.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hledger-lib-1.52.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hledger-lib-1.52.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hledger-lib
hs-libraries:         HShledger-lib-1.52.1-43HfShhLTNJHhMAwtVPfbH
depends:
    Decimal-0.5.2-1urRxDFvYHpBB1HI9Ls7Gz
    Glob-0.10.2-46NEPXotEWf6uAZhl3ly9w
    aeson-2.2.2.0-6vy5nFkYOklEBUzF5CRv7u
    aeson-pretty-0.8.11-BvvDjbHwDAyFeHzC2HVANG
    ansi-terminal-1.1-ISNPiouOT5KL4Fl392usuf array-0.5.6.0
    base-4.18.2.1 blaze-html-0.9.2.0-17FkYPGue7ZAHMHHyLr7B4
    blaze-markup-0.8.3.0-8nAkqh6ULumKoXEFXqqlfH bytestring-0.11.5.3
    call-stack-0.4.0-2YwW5DB9oZp9WckTZ0XzI6
    cassava-0.5.4.1-AEpRMw01iAkG9d9ZRt6Fzh
    cassava-megaparsec-2.1.1-UKtiFboxCaCL8ZeyAOVDk
    cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    colour-2.3.7-H5TqoHTy3mDsPdFk0yVV4 containers-0.6.7
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG deepseq-1.4.8.1
    directory-1.3.8.5 doclayout-0.5.0.3-19wYOTkFhQj7ga4Iw88MWl
    encoding-0.10.3-13g0xTqjRlXHMv7J9xbDsp
    extra-1.7.16-ENixoDflt6v9pdHnDueJL0
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    hashtables-1.4.2-DCIqrkMqUYY4VRMy0AxrAZ
    lucid-2.11.20260427-5Wv7REVgIE28L8OSzAO9db
    megaparsec-9.7.1-JXz5wEb4OUx5fCiSnZpt43
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-1JCZcjTuCbDB2Q9keDntvT mtl-2.3.1
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    pretty-simple-4.1.4.0-DaBMFhchWdM2C8tPrUwFfa process-1.6.19.0
    regex-tdfa-1.3.2.6-G1rwxCg3bOv6wSXzJT4zAX
    safe-0.3.21-242vtiZp8xiFH4MzHCK9jy
    tabular-0.2.2.8-Ly9fepE9sHFB2l1Bgv9bkV
    tasty-1.5.4-7y5W1ew2ZKj75dqOBUo0NY
    tasty-hunit-0.10.2-F7OiIFJ0eY2A5nPfcJ9IKy template-haskell-2.20.0.0
    terminal-size-0.3.4-RfZxi4foNwK9w669pzI7h text-2.0.2
    these-1.2.1-8b1XsW37fHKjRGbcPay34 time-1.12.2
    timeit-2.0-DwmItJuhuSm6aktMh1S1ZM transformers-0.6.1.0
    uglymemo-0.1.0.1-9CTAG7WaUP4YIMm3gIN93
    unordered-containers-0.2.21-CG6y7kseADB9y4YJD0dypo
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:   /usr/share/doc/haskell-hledger-lib/html/hledger-lib.haddock
haddock-html:         /usr/share/doc/haskell-hledger-lib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

